#
# spec file for package webvfx
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name mlt
%define mltversion 6.20.0
%define mltsoversion 6.20.0
%define sover 1
%define mltmaj %(echo %{mltversion} |cut -d "." -f 1)
# Find qt version used to build
%define qt5version %(pkg-config --modversion Qt5Core)
Name:           webvfx
Version:        1.2.0
Release:        lp152.2.2
Summary:        Video effects engine based on web technologies
License:        BSD-3-Clause
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://github.com/mltframework/webvfx
Source0:        %{_name}-%{mltversion}.tar.gz
# This is needed by shotcut and will only build within the mlt sources.
Source1:        https://github.com/mltframework/webvfx/archive/%{version}.tar.gz#/webvfx-%{version}.tar.gz
# PATCH-FIX-OPENSUSE libmlt-0.8.2-vdpau.patch reddwarf@opensuse.org -- Make VDPAU support work without the devel package
Patch1:         libmlt-0.8.2-vdpau.patch
#PATCH-FIX-UPSTREAM webvfx-versioned-libdir.patch davejplater@gmail.com -- install webvfx lib in versioned _libdir
Patch10:        webvfx-versioned-libdir.patch
Patch11:        webvfx-nobrowser.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.5.0
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(mlt++) = %{mltversion}
BuildRequires:  pkgconfig(mlt-framework) = %{mltversion}

%description
WebVfx is a video effects library that allows effects to be
implemented using WebKit HTML or Qt QML.

%package -n libwebvfx%{sover}
Summary:        Video effects engine based on web technologies
Group:          System/Libraries

%description -n libwebvfx%{sover}
WebVfx is a video effects library that allows effects to be
implemented using WebKit HTML or Qt QML.

%package devel
Summary:        Video effects engine based on web technologies
Group:          Development/Libraries/C and C++
Requires:       libwebvfx%{sover} = %{version}
Requires:       pkgconfig(mlt-framework) = %{mltsoversion}

%description devel
WebVfx is a video effects library that allows effects to be
implemented using WebKit HTML or Qt QML. This package contains
the development library link.

%package module
Summary:        Webvfx module for MLT
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description module
A module plugin for the MLT multimedia framework.

%package -n qmelt
Summary:        A Melt that works with webvfx
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description -n qmelt
MLT is a multimedia framework, designed and developed for television
broadcasting. It provides a toolkit for broadcasters, video editors,
media players, transcoders, web streamers and many more types of
applications. The functionality of the system is provided via an
assortment of tools, XML authoring components, and an plug-in based API.

%prep
%setup -q -n %{_name}-%{mltversion} -a 1
%autopatch -p0

%build
pushd webvfx-%{version}
%qmake5 \
	QMAKE_STRIP="" \
	MLT_SOURCE="%{_builddir}/%{_name}-%{mltversion}/" \
	WLIB=%{_lib} \
        PREFIX="%{_prefix}" -Wall -recursive

make VERBOSE=1 %{?_smp_mflags}
popd

%install
pushd webvfx-%{version}
%qmake5_install
chmod 0644 LICENSE README.md
popd
#Add webvfx module to versioned mlt module directory
mv %{buildroot}%{_libdir}/mlt %{buildroot}%{_libdir}/mlt-%{mltmaj}
chmod 0755 %{buildroot}%{_bindir}/*
#Create man pages for executables.
mkdir -p %{buildroot}%{_mandir}/man1
pushd %{buildroot}%{_bindir}
for i in *; do
	help2man -N --no-discard-stderr -h "-help" -v "-version" ./${i} -o %{buildroot}%{_mandir}/man1/${i}.1 || touch %{buildroot}%{_mandir}/man1/${i}.1
done
popd

%post -n libwebvfx%{sover} -p /sbin/ldconfig
%postun -n libwebvfx%{sover} -p /sbin/ldconfig

%files
%{_bindir}/webvfx*
%{_mandir}/man1/webvfx*
%license webvfx-%{version}/LICENSE
%doc webvfx-%{version}/README.md

%files module
%defattr(0755, root, root, 0755)
%{_libdir}/mlt-%{mltmaj}/

%files -n libwebvfx%{sover}
%defattr(0755, root, root, 0755)
%{_libdir}/libwebvfx.so.*

%files devel
%defattr(0755, root, root, 0755)
%{_libdir}/libwebvfx.so

%files -n qmelt
%{_bindir}/qmelt
%{_mandir}/man1/qmelt*

%changelog
* Mon Feb 17 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.2.0
  * This version adds support for MLT v6.20.0's preview
    scaling.
  * For the MLT integration, if the resource starts with
    "plain:" webvfx does automatic scaling per the zoom level.
    This works fine for content that is simply produced or
    overlayed by the filter. However, content that uses the
    webvfx JavaScript extension will not operate with zoom
    unless the service property mlt_resolution_scale is set to
    1.
    New properties mlt_profile_scale_width and
    mlt_profile_scale_height as real numbers that reflect the
    new MLT consumer scale property used to do low-res preview
    scaling. Content script can access this via
    webvfx.getNumberParameter() to scale its parameters and
    elements.
- Refreshed webvfx-versioned-libdir.patch and
  webvfx-nobrowser.patch
* Tue Nov 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.0
  * Added support for alpha channels in MLT video for input and
    output.
  * Added a transparent property to the MLT filter. When the
    property is set to 1, this gives a filter a transparent white
    canvas for drawing while the MLT video image is still
    available through the JavaScript extension. This facilitates
    using WebVfx to draw the alpha channel independently of the
    MLT alpha channel.
  * Added support for getting a MLT rectangle property
    (mlt_rect) as a JavaScript object with properties: x, y,
    width, height, and opacity.
- Refreshed webvfx-versioned-libdir.patch and
  webvfx-nobrowser.patch
* Thu Jan 10 2019 davejplater@gmail.com
- Update to release version 1.0.0
- Add webvfx-nobrowser.patch to fix Factory build.
- Upstream changes:
  Set version to 1.0.0
* Sun May  6 2018 davejplater@gmail.com
- Update to version 0.44+git20180523
- Rebase webvfx-versioned-libdir.patch.
- Upstream changes:
  * check pointers before using them.
* Sun Mar 11 2018 davejplater@gmail.com
- Fix Leap:15.0 build and run spec-cleaner.
* Wed Jan 24 2018 davejplater@gmail.com
- Removed mlt patches:
  6c658e5d8cd11933bf799a2a985aa4b24cfbcb60.patch,
  libmlt-nomorexlocale_h.patch, em_close.patch and
  use-recommended-freetype-include.patch.
- Package LICENSE and README.md.
* Fri Aug 25 2017 davejplater@gmail.com
- Apply all mlt patches before building.
* Thu Jul  6 2017 jengelh@inai.de
- Trim filler wording from descriptions; fix identical
  descriptions being used in different subpackages.
- Cure "useless use of cat" (`ls -1`) by replacing with just *.
* Sun Jun 11 2017 davejplater@gmail.com
- Added man pages for binaries.
* Thu Jun  8 2017 davejplater@gmail.com
- Created initial package version 0.44+git20160823 from current
  git rev: e918ce4667e623c3d60735cb898223e730c6d7af needed by
  shotcut. See boo#1043070
- Added webvfx-versioned-libdir.patch to enable arch dependent
  library directory install
